.. currentmodule:: nbutils

=================
Developer's notes
=================

Source code
~~~~~~~~~~~

The source code is currently `available on GitHub`_ under the terms and
conditions of the :ref:`MIT license <license>`. Fork away!

Bug reports
~~~~~~~~~~~

To search for bugs or report them, please use the Bug Tracker at:

    https://github.com/jeremiedecock/python-nbutils/issues

Contribute
~~~~~~~~~~

This project is written for Python 3.x.
Python 2.x is *not* supported.

The `TODO.md`_ file contains the TODO list.

All contributions should at least comply with the following PEPs_:

- PEP8_ "Python's good practices"
- PEP257_ "Docstring Conventions"
- PEP287_ "reStructuredText Docstring Format"

All contribution should be properly documented and tested with unittest_
and/or doctest_.

pylint_, `pep8 <https://github.com/PyCQA/pep8>`__ and pyflakes_ should also be
used to check the quality of each module.

Docstrings should be compatible with the
`Sphinx "napoleon" extension <http://sphinxcontrib-napoleon.readthedocs.org/>`__
and follow the Numpy style:

- `Please follow this guide <https://github.com/numpy/numpy/blob/master/doc/HOWTO_DOCUMENT.rst.txt>`__
- `Be inspired by these examples <http://sphinxcontrib-napoleon.readthedocs.io/en/latest/example_numpy.html>`__

Changes
~~~~~~~

.. include:: ../CHANGES.rst
   :start-line: 2

.. ......................................................................... ..

.. _PEP8: https://www.python.org/dev/peps/pep-0008/
.. _PEP257: https://www.python.org/dev/peps/pep-0257/
.. _PEP287: https://www.python.org/dev/peps/pep-0287/
.. _PEPs: https://www.python.org/dev/peps/
.. _unittest: https://docs.python.org/3/library/unittest.html
.. _doctest: https://docs.python.org/3/library/doctest.html
.. _pylint: http://www.pylint.org/
.. _pyflakes: https://pypi.python.org/pypi/pyflakes

.. _available on GitHub: https://github.com/jeremiedecock/python-nbutils
.. _TODO.md: https://github.com/jeremiedecock/python-nbutils/blob/master/TODO.md

